$Title Education model
$maxcol 300
$onsymlist
$onsymxref
$oninline
options nlp=minos ;
$ontext

$offtext

sets
  j    Education sectors (Pre LDC FDC Occ) / Pre, LDC, FDC, OCC /
  n    Labour types (Bachelor Diploma CertIII-IV CertI-II Unqual) / B, A, C3, C1, U /
  timrep / Base,  R1*R36 /
;
alias (j,jp) ;


Scalars
  y
;



Parameters
*parameters for calibration
  qdbar(j)
  pdbar(j)
  psbar(j)
  kbar(j)
  rbar(j)
  ldbar(j,n)
  lsbar(n)
  wbar(n)
  oAbar(j)
  oSbar(j)
  sCCBbar(j)
  sOTHbar(j)
  eDP(j)
  eDY(j)
  eKQ(j)
  eKR(j)
  eLW(n)
  eLP(j,n)

*Calculated parameters
  aDI(j)
  bDI(j)
  cDI(j)
  aLI(n)
  bLI(n)
  cLI(j,n)
  aKI(j)
  bKI(j)
  cKI(j)
  aD(j)
  bD(j)
  cD(j)
  aL(n)
  bL(n)
  cL(j,n)
  aK(j)
  bK(j)
  cK(j)
  mL(j,n)
  mK(j)
  sCCB(j)
  sOTH(j)

* reporting parameters
ReportQd(j,*)
ReportQs(j,*)
ReportPd(j,*)
ReportPs(j,*)
ReportLd(n,j,*)
ReportLs(n,*)
ReportKd(j,*)
ReportKs(j,*)
ReportW(n,*)
ReportoS(j,*)
IndScen(*,j,timrep)
;

$include zdata6.gms
$include zcalc6.gms



Free variables
  NSW  net social welfare (marshallian C+P surplus)
  oS(j)
  oA(j)
;

Positive variables
  Qd(j)   Demand quantity for services of type j
  Qs(j)   Supply quantity for services of type j
  Ld(j,n) Demand for labour of type n from sector j
  Ls(n)   Supply of labour of type n
  Kd(j)   Demand for capital from sector j
  Ks(j)   Supply of capital for sector j
  S(j)    Quality of output in sector j
  W(n)    Wage rate of labour of type n
  R(j)    Rental rate of capital in sector j
  Pd(j)   Demand price for sector j
  Ps(j)   Supply price for sector j
;

Free variables
  ExpA    Total Australian government spending on the ECD sector
  ExpS    Total state and territory government spending on the ECD sector
  ExpH    Total household spending on the ECD sector
  ExpT    Total spending on the ECD sector
;

Equations
  Eq_ObjfnNSW   Objective function nsw
  Eq_KdsBal(j)  Capital demand-supply balance equation for sector j
  Eq_Kd(j)      Capital demand from sector j
  Eq_Ks(j)      Capital supply for sector j
  Eq_Ks2(j)     Capital supply for sector j (2)
  Eq_LdsBal(n)  Labour demand-supply balance equation for labour type n
  Eq_Ld(j,n)    Labour demand from sector j for labour type n
  Eq_Ls(n)      Labour supply equation for labour of type n
  Eq_Ls_full(n) Labour supply equation for labour of type n (full Ilias model)
  Eq_QdsBal(j)  Output demand-supply balance equation for sector j
  Eq_PdsBal(j)  Price demand-supply balance equation for sector j
  Eq_Ps(j)      Supply price equation for sector j
  Eq_Ps2(j)     Supply price equation for sector j (2)
  Eq_Pd(j)      Demand price equation for sector j
  Eq_Subs(j)    Subsidy equations
  Eq_ExpA       Total Australian government spending on the ECD sector
  Eq_ExpS       Total state and territory government spending on the ECD sector
  Eq_ExpH    Total household spending on the ECD sector
  Eq_ExpT    Total spending on the ECD sector
;



* Demand integral with respect to Q less cost integrals (CS + PS)
Eq_ObjfnNSW..
  nsw =e=
          sum[ j , (aD(j) + cD(j)*y)*Qd(j) + 0.5*bD(j)*Qd(j)*Qd(j)]
          - sum[ n ,
                     [aL(n) + sum[j,cL(j,n)*Ps(j)]]
                     *Ls(n)
                     + 0.5*bL(n)*Ls(n)*Ls(n) ]
          - sum[ j , R(j)*Ks(j)]

  ;



Eq_QdsBal(j)..
  Qd(j) - Qs(j) =l= 0 ;
Eq_PdsBal(j)..
  Pd(j) - Ps(j) =e= 0 ;
Eq_Pd(j)..
  Pd(j) =e= aD(j) + cD(j)*y + bD(j)*Qd(j) ;
Eq_Ps(j)..
  Ps(j) =e= (sum[ n , W(n)*Ld(j,n)] + R(j)*Kd(j) - R(j)*(aK(j) + cK(j)*R(j)) )/ Qs(j) ;



Eq_Ld(j,n)..
  Ld(j,n) =e= 1 / mL(j,n) * Qs(j) ;
Eq_Ls(n)..
  W(n) =e= [aL(n) + sum[j,cL(j,n)*Ps(j)] ] + bL(n)*Ls(n) ;
Eq_LdsBal(n)..
  sum[ j , Ld(j,n) ] =e= Ls(n) ;




Eq_Kd(j)..
  Kd(j) =e= aK(j) + bK(j) * Qs(j) + cK(j)*R(j) ;
Eq_Ks2(j)..
  R(j) =e= rbar(j) ;
Eq_KdsBal(j)..
  Kd(j) =e= Ks(j) ;
Eq_Ks(j)..
  Ks(j) =e= kbar(j) ;



*** Policy constraints ***
Eq_Subs(j)..
   Pd(j) =e= (Ps(j)*(1-oS(j)) - sCCB(j) - sOTH(j))*(1-oA(j)) ;

*** Gov't expenditures
Eq_ExpA..
ExpA =e= sum[ j , oA(j)*(Ps(j)*(1-oS(j)) - sCCB(j) - sOTH(j))*Qd(j)
                  + (sCCB(j) + sOTH(j))*Qd(j) ]  ;

Eq_ExpS..
ExpS =e= sum[ j , oS(j)*Ps(j)*Qd(j) ] ;

Eq_ExpH..
ExpH =e= sum[ j , (Ps(j)*(1-oS(j)) - sCCB(j) - sOTH(j))*(1-oA(j))*Qd(j) ] ;

Eq_ExpT..
ExpT =e= sum[ j , Ps(j)*Qd(j) ] ;




model Policy
/   Eq_ObjfnNSW,
    Eq_QdsBal,
    Eq_Pd,
    Eq_Ps,
    Eq_Ld,
    Eq_Ls,
    Eq_LdsBal,
    Eq_Kd,
    Eq_Ks2,
    Eq_KdsBal
    Eq_Subs,

    Eq_ExpA
    Eq_ExpS
    Eq_ExpH
    Eq_ExpT

/ ;



Qd.lo(j) = 0.0005 ;
Qs.lo(j) = 0.0005 ;
Ld.lo(j,n) = 0.0005 ;
Ls.lo(n) = 0.0005 ;
Kd.lo(j) = 0.0005 ;
Ks.lo(j) = 0.0005 ;
S.lo(j) = 0.0005 ;
W.lo(n) = 0.0005 ;
R.lo(j) = 0.0005 ;
Pd.lo(j) = 0.0005 ;
Ps.lo(j) = 0.0005 ;


oS.fx(j) = oSbar(j) ;
oA.fx(j) = oAbar(j) ;



* Fix the price of preschool services, enable state/territory subsidy to vary
oS.lo('Pre') = -1.0 ;
oS.up('Pre') = 1.0 ;
Pd.fx('Pre') = pdbar('Pre') ;


* Solving for the Base Case

$include zdata6.gms
$include MidOwnPrice6.gms
$include MidElasticity6.gms
$include SupplyElas6.gms
$include zcalc6.gms

solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'Base') = Qd.l(j);
IndScen('Pd',j,'Base') = Pd.l(j);
IndScen('Ps',j,'Base') = Ps.l(j);
IndScen('oS',j,'Base') = oS.l(j);
IndScen('oA',j,'Base') = oA.l(j);
IndScen('LdRB',j,'Base') = Ld.l(j,'B');
IndScen('LdRA',j,'Base') = Ld.l(j,'A');
IndScen('LdRC3',j,'Base') = Ld.l(j,'C3');
IndScen('LdRC1',j,'Base') = Ld.l(j,'C1');
IndScen('LdRU',j,'Base') = Ld.l(j,'U');
IndScen('Kd',j,'Base') = Kd.l(j);
IndScen('WRB',j,'Base') = W.l('B');
IndScen('WRA',j,'Base') = W.l('A');
IndScen('WRC3',j,'Base') = W.l('C3');
IndScen('WRC1',j,'Base') = W.l('C1');
IndScen('WRU',j,'Base') = W.l('U');
IndScen('ExpA',j,'Base') = ExpA.l;
IndScen('ExpS',j,'Base') = ExpS.l;
IndScen('ExpH',j,'Base') = ExpH.l;
IndScen('ExpT',j,'Base') = ExpT.l;

parameter BasePrices(j) ;
BasePrices(j) = Pd.l(j) ;





* Fix the price of preschool services, enable state/territory subsidy to vary
oS.lo('Pre') = -1.0 ;
oS.up('Pre') = 1.0 ;
Pd.fx('Pre') = BasePrices('Pre') ;



* (***) Scenario 1
$include zdata6.gms
$include LowOwnPrice6.gms
$include LowElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R1') = Qd.l(j);
IndScen('Pd',j,'R1') = Pd.l(j);
IndScen('Ps',j,'R1') = Ps.l(j);
IndScen('oS',j,'R1') = oS.l(j);
IndScen('oA',j,'R1') = oA.l(j);
IndScen('LdRB',j,'R1') = Ld.l(j,'B');
IndScen('LdRA',j,'R1') = Ld.l(j,'A');
IndScen('LdRC3',j,'R1') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R1') = Ld.l(j,'C1');
IndScen('LdRU',j,'R1') = Ld.l(j,'U');
IndScen('Kd',j,'R1') = Kd.l(j);
IndScen('WRB',j,'R1') = W.l('B');
IndScen('WRA',j,'R1') = W.l('A');
IndScen('WRC3',j,'R1') = W.l('C3');
IndScen('WRC1',j,'R1') = W.l('C1');
IndScen('WRU',j,'R1') = W.l('U');
IndScen('ExpA',j,'R1') = ExpA.l;
IndScen('ExpS',j,'R1') = ExpS.l;
IndScen('ExpH',j,'R1') = ExpH.l;
IndScen('ExpT',j,'R1') = ExpT.l;

* (***) Scenario 2
$include zdata6.gms
$include MidOwnPrice6.gms
$include LowElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R2') = Qd.l(j);
IndScen('Pd',j,'R2') = Pd.l(j);
IndScen('Ps',j,'R2') = Ps.l(j);
IndScen('oS',j,'R2') = oS.l(j);
IndScen('oA',j,'R2') = oA.l(j);
IndScen('LdRB',j,'R2') = Ld.l(j,'B');
IndScen('LdRA',j,'R2') = Ld.l(j,'A');
IndScen('LdRC3',j,'R2') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R2') = Ld.l(j,'C1');
IndScen('LdRU',j,'R2') = Ld.l(j,'U');
IndScen('Kd',j,'R2') = Kd.l(j);
IndScen('WRB',j,'R2') = W.l('B');
IndScen('WRA',j,'R2') = W.l('A');
IndScen('WRC3',j,'R2') = W.l('C3');
IndScen('WRC1',j,'R2') = W.l('C1');
IndScen('WRU',j,'R2') = W.l('U');
IndScen('ExpA',j,'R2') = ExpA.l;
IndScen('ExpS',j,'R2') = ExpS.l;
IndScen('ExpH',j,'R2') = ExpH.l;
IndScen('ExpT',j,'R2') = ExpT.l;

* (***) Scenario 3
$include zdata6.gms
$include HighOwnPrice6.gms
$include LowElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R3') = Qd.l(j);
IndScen('Pd',j,'R3') = Pd.l(j);
IndScen('Ps',j,'R3') = Ps.l(j);
IndScen('oS',j,'R3') = oS.l(j);
IndScen('oA',j,'R3') = oA.l(j);
IndScen('LdRB',j,'R3') = Ld.l(j,'B');
IndScen('LdRA',j,'R3') = Ld.l(j,'A');
IndScen('LdRC3',j,'R3') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R3') = Ld.l(j,'C1');
IndScen('LdRU',j,'R3') = Ld.l(j,'U');
IndScen('Kd',j,'R3') = Kd.l(j);
IndScen('WRB',j,'R3') = W.l('B');
IndScen('WRA',j,'R3') = W.l('A');
IndScen('WRC3',j,'R3') = W.l('C3');
IndScen('WRC1',j,'R3') = W.l('C1');
IndScen('WRU',j,'R3') = W.l('U');
IndScen('ExpA',j,'R3') = ExpA.l;
IndScen('ExpS',j,'R3') = ExpS.l;
IndScen('ExpH',j,'R3') = ExpH.l;
IndScen('ExpT',j,'R3') = ExpT.l;

* (***) Scenario 4
$include zdata6.gms
$include LowOwnPrice6.gms
$include MidElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R4') = Qd.l(j);
IndScen('Pd',j,'R4') = Pd.l(j);
IndScen('Ps',j,'R4') = Ps.l(j);
IndScen('oS',j,'R4') = oS.l(j);
IndScen('oA',j,'R4') = oA.l(j);
IndScen('LdRB',j,'R4') = Ld.l(j,'B');
IndScen('LdRA',j,'R4') = Ld.l(j,'A');
IndScen('LdRC3',j,'R4') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R4') = Ld.l(j,'C1');
IndScen('LdRU',j,'R4') = Ld.l(j,'U');
IndScen('Kd',j,'R4') = Kd.l(j);
IndScen('WRB',j,'R4') = W.l('B');
IndScen('WRA',j,'R4') = W.l('A');
IndScen('WRC3',j,'R4') = W.l('C3');
IndScen('WRC1',j,'R4') = W.l('C1');
IndScen('WRU',j,'R4') = W.l('U');
IndScen('ExpA',j,'R4') = ExpA.l;
IndScen('ExpS',j,'R4') = ExpS.l;
IndScen('ExpH',j,'R4') = ExpH.l;
IndScen('ExpT',j,'R4') = ExpT.l;

* (***) Scenario 5
$include zdata6.gms
$include MidOwnPrice6.gms
$include MidElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R5') = Qd.l(j);
IndScen('Pd',j,'R5') = Pd.l(j);
IndScen('Ps',j,'R5') = Ps.l(j);
IndScen('oS',j,'R5') = oS.l(j);
IndScen('oA',j,'R5') = oA.l(j);
IndScen('LdRB',j,'R5') = Ld.l(j,'B');
IndScen('LdRA',j,'R5') = Ld.l(j,'A');
IndScen('LdRC3',j,'R5') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R5') = Ld.l(j,'C1');
IndScen('LdRU',j,'R5') = Ld.l(j,'U');
IndScen('Kd',j,'R5') = Kd.l(j);
IndScen('WRB',j,'R5') = W.l('B');
IndScen('WRA',j,'R5') = W.l('A');
IndScen('WRC3',j,'R5') = W.l('C3');
IndScen('WRC1',j,'R5') = W.l('C1');
IndScen('WRU',j,'R5') = W.l('U');
IndScen('ExpA',j,'R5') = ExpA.l;
IndScen('ExpS',j,'R5') = ExpS.l;
IndScen('ExpH',j,'R5') = ExpH.l;
IndScen('ExpT',j,'R5') = ExpT.l;

* (***) Scenario 6
$include zdata6.gms
$include HighOwnPrice6.gms
$include MidElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R6') = Qd.l(j);
IndScen('Pd',j,'R6') = Pd.l(j);
IndScen('Ps',j,'R6') = Ps.l(j);
IndScen('oS',j,'R6') = oS.l(j);
IndScen('oA',j,'R6') = oA.l(j);
IndScen('LdRB',j,'R6') = Ld.l(j,'B');
IndScen('LdRA',j,'R6') = Ld.l(j,'A');
IndScen('LdRC3',j,'R6') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R6') = Ld.l(j,'C1');
IndScen('LdRU',j,'R6') = Ld.l(j,'U');
IndScen('Kd',j,'R6') = Kd.l(j);
IndScen('WRB',j,'R6') = W.l('B');
IndScen('WRA',j,'R6') = W.l('A');
IndScen('WRC3',j,'R6') = W.l('C3');
IndScen('WRC1',j,'R6') = W.l('C1');
IndScen('WRU',j,'R6') = W.l('U');
IndScen('ExpA',j,'R6') = ExpA.l;
IndScen('ExpS',j,'R6') = ExpS.l;
IndScen('ExpH',j,'R6') = ExpH.l;
IndScen('ExpT',j,'R6') = ExpT.l;

* (***) Scenario 7
$include zdata6.gms
$include LowOwnPrice6.gms
$include HighElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R7') = Qd.l(j);
IndScen('Pd',j,'R7') = Pd.l(j);
IndScen('Ps',j,'R7') = Ps.l(j);
IndScen('oS',j,'R7') = oS.l(j);
IndScen('oA',j,'R7') = oA.l(j);
IndScen('LdRB',j,'R7') = Ld.l(j,'B');
IndScen('LdRA',j,'R7') = Ld.l(j,'A');
IndScen('LdRC3',j,'R7') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R7') = Ld.l(j,'C1');
IndScen('LdRU',j,'R7') = Ld.l(j,'U');
IndScen('Kd',j,'R7') = Kd.l(j);
IndScen('WRB',j,'R7') = W.l('B');
IndScen('WRA',j,'R7') = W.l('A');
IndScen('WRC3',j,'R7') = W.l('C3');
IndScen('WRC1',j,'R7') = W.l('C1');
IndScen('WRU',j,'R7') = W.l('U');
IndScen('ExpA',j,'R7') = ExpA.l;
IndScen('ExpS',j,'R7') = ExpS.l;
IndScen('ExpH',j,'R7') = ExpH.l;
IndScen('ExpT',j,'R7') = ExpT.l;

* (***) Scenario 8
$include zdata6.gms
$include MidOwnPrice6.gms
$include HighElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R8') = Qd.l(j);
IndScen('Pd',j,'R8') = Pd.l(j);
IndScen('Ps',j,'R8') = Ps.l(j);
IndScen('oS',j,'R8') = oS.l(j);
IndScen('oA',j,'R8') = oA.l(j);
IndScen('LdRB',j,'R8') = Ld.l(j,'B');
IndScen('LdRA',j,'R8') = Ld.l(j,'A');
IndScen('LdRC3',j,'R8') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R8') = Ld.l(j,'C1');
IndScen('LdRU',j,'R8') = Ld.l(j,'U');
IndScen('Kd',j,'R8') = Kd.l(j);
IndScen('WRB',j,'R8') = W.l('B');
IndScen('WRA',j,'R8') = W.l('A');
IndScen('WRC3',j,'R8') = W.l('C3');
IndScen('WRC1',j,'R8') = W.l('C1');
IndScen('WRU',j,'R8') = W.l('U');
IndScen('ExpA',j,'R8') = ExpA.l;
IndScen('ExpS',j,'R8') = ExpS.l;
IndScen('ExpH',j,'R8') = ExpH.l;
IndScen('ExpT',j,'R8') = ExpT.l;

* (***) Scenario 9
$include zdata6.gms
$include HighOwnPrice6.gms
$include HighElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R9') = Qd.l(j);
IndScen('Pd',j,'R9') = Pd.l(j);
IndScen('Ps',j,'R9') = Ps.l(j);
IndScen('oS',j,'R9') = oS.l(j);
IndScen('oA',j,'R9') = oA.l(j);
IndScen('LdRB',j,'R9') = Ld.l(j,'B');
IndScen('LdRA',j,'R9') = Ld.l(j,'A');
IndScen('LdRC3',j,'R9') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R9') = Ld.l(j,'C1');
IndScen('LdRU',j,'R9') = Ld.l(j,'U');
IndScen('Kd',j,'R9') = Kd.l(j);
IndScen('WRB',j,'R9') = W.l('B');
IndScen('WRA',j,'R9') = W.l('A');
IndScen('WRC3',j,'R9') = W.l('C3');
IndScen('WRC1',j,'R9') = W.l('C1');
IndScen('WRU',j,'R9') = W.l('U');
IndScen('ExpA',j,'R9') = ExpA.l;
IndScen('ExpS',j,'R9') = ExpS.l;
IndScen('ExpH',j,'R9') = ExpH.l;
IndScen('ExpT',j,'R9') = ExpT.l;

* (***) Scenario 10
$include zdata6.gms
$include LowOwnPrice6.gms
$include LowElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R10') = Qd.l(j);
IndScen('Pd',j,'R10') = Pd.l(j);
IndScen('Ps',j,'R10') = Ps.l(j);
IndScen('oS',j,'R10') = oS.l(j);
IndScen('oA',j,'R10') = oA.l(j);
IndScen('LdRB',j,'R10') = Ld.l(j,'B');
IndScen('LdRA',j,'R10') = Ld.l(j,'A');
IndScen('LdRC3',j,'R10') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R10') = Ld.l(j,'C1');
IndScen('LdRU',j,'R10') = Ld.l(j,'U');
IndScen('Kd',j,'R10') = Kd.l(j);
IndScen('WRB',j,'R10') = W.l('B');
IndScen('WRA',j,'R10') = W.l('A');
IndScen('WRC3',j,'R10') = W.l('C3');
IndScen('WRC1',j,'R10') = W.l('C1');
IndScen('WRU',j,'R10') = W.l('U');
IndScen('ExpA',j,'R10') = ExpA.l;
IndScen('ExpS',j,'R10') = ExpS.l;
IndScen('ExpH',j,'R10') = ExpH.l;
IndScen('ExpT',j,'R10') = ExpT.l;

* (***) Scenario 11
$include zdata6.gms
$include MidOwnPrice6.gms
$include LowElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R11') = Qd.l(j);
IndScen('Pd',j,'R11') = Pd.l(j);
IndScen('Ps',j,'R11') = Ps.l(j);
IndScen('oS',j,'R11') = oS.l(j);
IndScen('oA',j,'R11') = oA.l(j);
IndScen('LdRB',j,'R11') = Ld.l(j,'B');
IndScen('LdRA',j,'R11') = Ld.l(j,'A');
IndScen('LdRC3',j,'R11') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R11') = Ld.l(j,'C1');
IndScen('LdRU',j,'R11') = Ld.l(j,'U');
IndScen('Kd',j,'R11') = Kd.l(j);
IndScen('WRB',j,'R11') = W.l('B');
IndScen('WRA',j,'R11') = W.l('A');
IndScen('WRC3',j,'R11') = W.l('C3');
IndScen('WRC1',j,'R11') = W.l('C1');
IndScen('WRU',j,'R11') = W.l('U');
IndScen('ExpA',j,'R11') = ExpA.l;
IndScen('ExpS',j,'R11') = ExpS.l;
IndScen('ExpH',j,'R11') = ExpH.l;
IndScen('ExpT',j,'R11') = ExpT.l;

* (***) Scenario 12
$include zdata6.gms
$include HighOwnPrice6.gms
$include LowElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R12') = Qd.l(j);
IndScen('Pd',j,'R12') = Pd.l(j);
IndScen('Ps',j,'R12') = Ps.l(j);
IndScen('oS',j,'R12') = oS.l(j);
IndScen('oA',j,'R12') = oA.l(j);
IndScen('LdRB',j,'R12') = Ld.l(j,'B');
IndScen('LdRA',j,'R12') = Ld.l(j,'A');
IndScen('LdRC3',j,'R12') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R12') = Ld.l(j,'C1');
IndScen('LdRU',j,'R12') = Ld.l(j,'U');
IndScen('Kd',j,'R12') = Kd.l(j);
IndScen('WRB',j,'R12') = W.l('B');
IndScen('WRA',j,'R12') = W.l('A');
IndScen('WRC3',j,'R12') = W.l('C3');
IndScen('WRC1',j,'R12') = W.l('C1');
IndScen('WRU',j,'R12') = W.l('U');
IndScen('ExpA',j,'R12') = ExpA.l;
IndScen('ExpS',j,'R12') = ExpS.l;
IndScen('ExpH',j,'R12') = ExpH.l;
IndScen('ExpT',j,'R12') = ExpT.l;

* (***) Scenario 13
$include zdata6.gms
$include LowOwnPrice6.gms
$include MidElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R13') = Qd.l(j);
IndScen('Pd',j,'R13') = Pd.l(j);
IndScen('Ps',j,'R13') = Ps.l(j);
IndScen('oS',j,'R13') = oS.l(j);
IndScen('oA',j,'R13') = oA.l(j);
IndScen('LdRB',j,'R13') = Ld.l(j,'B');
IndScen('LdRA',j,'R13') = Ld.l(j,'A');
IndScen('LdRC3',j,'R13') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R13') = Ld.l(j,'C1');
IndScen('LdRU',j,'R13') = Ld.l(j,'U');
IndScen('Kd',j,'R13') = Kd.l(j);
IndScen('WRB',j,'R13') = W.l('B');
IndScen('WRA',j,'R13') = W.l('A');
IndScen('WRC3',j,'R13') = W.l('C3');
IndScen('WRC1',j,'R13') = W.l('C1');
IndScen('WRU',j,'R13') = W.l('U');
IndScen('ExpA',j,'R13') = ExpA.l;
IndScen('ExpS',j,'R13') = ExpS.l;
IndScen('ExpH',j,'R13') = ExpH.l;
IndScen('ExpT',j,'R13') = ExpT.l;

* (***) Scenario 14
$include zdata6.gms
$include MidOwnPrice6.gms
$include MidElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R14') = Qd.l(j);
IndScen('Pd',j,'R14') = Pd.l(j);
IndScen('Ps',j,'R14') = Ps.l(j);
IndScen('oS',j,'R14') = oS.l(j);
IndScen('oA',j,'R14') = oA.l(j);
IndScen('LdRB',j,'R14') = Ld.l(j,'B');
IndScen('LdRA',j,'R14') = Ld.l(j,'A');
IndScen('LdRC3',j,'R14') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R14') = Ld.l(j,'C1');
IndScen('LdRU',j,'R14') = Ld.l(j,'U');
IndScen('Kd',j,'R14') = Kd.l(j);
IndScen('WRB',j,'R14') = W.l('B');
IndScen('WRA',j,'R14') = W.l('A');
IndScen('WRC3',j,'R14') = W.l('C3');
IndScen('WRC1',j,'R14') = W.l('C1');
IndScen('WRU',j,'R14') = W.l('U');
IndScen('ExpA',j,'R14') = ExpA.l;
IndScen('ExpS',j,'R14') = ExpS.l;
IndScen('ExpH',j,'R14') = ExpH.l;
IndScen('ExpT',j,'R14') = ExpT.l;



* (***) Scenario 15
$include zdata6.gms
$include HighOwnPrice6.gms
$include MidElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R15') = Qd.l(j);
IndScen('Pd',j,'R15') = Pd.l(j);
IndScen('Ps',j,'R15') = Ps.l(j);
IndScen('oS',j,'R15') = oS.l(j);
IndScen('oA',j,'R15') = oA.l(j);
IndScen('LdRB',j,'R15') = Ld.l(j,'B');
IndScen('LdRA',j,'R15') = Ld.l(j,'A');
IndScen('LdRC3',j,'R15') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R15') = Ld.l(j,'C1');
IndScen('LdRU',j,'R15') = Ld.l(j,'U');
IndScen('Kd',j,'R15') = Kd.l(j);
IndScen('WRB',j,'R15') = W.l('B');
IndScen('WRA',j,'R15') = W.l('A');
IndScen('WRC3',j,'R15') = W.l('C3');
IndScen('WRC1',j,'R15') = W.l('C1');
IndScen('WRU',j,'R15') = W.l('U');
IndScen('ExpA',j,'R15') = ExpA.l;
IndScen('ExpS',j,'R15') = ExpS.l;
IndScen('ExpH',j,'R15') = ExpH.l;
IndScen('ExpT',j,'R15') = ExpT.l;

* (***) Scenario 16
$include zdata6.gms
$include LowOwnPrice6.gms
$include HighElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R16') = Qd.l(j);
IndScen('Pd',j,'R16') = Pd.l(j);
IndScen('Ps',j,'R16') = Ps.l(j);
IndScen('oS',j,'R16') = oS.l(j);
IndScen('oA',j,'R16') = oA.l(j);
IndScen('LdRB',j,'R16') = Ld.l(j,'B');
IndScen('LdRA',j,'R16') = Ld.l(j,'A');
IndScen('LdRC3',j,'R16') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R16') = Ld.l(j,'C1');
IndScen('LdRU',j,'R16') = Ld.l(j,'U');
IndScen('Kd',j,'R16') = Kd.l(j);
IndScen('WRB',j,'R16') = W.l('B');
IndScen('WRA',j,'R16') = W.l('A');
IndScen('WRC3',j,'R16') = W.l('C3');
IndScen('WRC1',j,'R16') = W.l('C1');
IndScen('WRU',j,'R16') = W.l('U');
IndScen('ExpA',j,'R16') = ExpA.l;
IndScen('ExpS',j,'R16') = ExpS.l;
IndScen('ExpH',j,'R16') = ExpH.l;
IndScen('ExpT',j,'R16') = ExpT.l;

* (***) Scenario 17
$include zdata6.gms
$include MidOwnPrice6.gms
$include HighElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R17') = Qd.l(j);
IndScen('Pd',j,'R17') = Pd.l(j);
IndScen('Ps',j,'R17') = Ps.l(j);
IndScen('oS',j,'R17') = oS.l(j);
IndScen('oA',j,'R17') = oA.l(j);
IndScen('LdRB',j,'R17') = Ld.l(j,'B');
IndScen('LdRA',j,'R17') = Ld.l(j,'A');
IndScen('LdRC3',j,'R17') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R17') = Ld.l(j,'C1');
IndScen('LdRU',j,'R17') = Ld.l(j,'U');
IndScen('Kd',j,'R17') = Kd.l(j);
IndScen('WRB',j,'R17') = W.l('B');
IndScen('WRA',j,'R17') = W.l('A');
IndScen('WRC3',j,'R17') = W.l('C3');
IndScen('WRC1',j,'R17') = W.l('C1');
IndScen('WRU',j,'R17') = W.l('U');
IndScen('ExpA',j,'R17') = ExpA.l;
IndScen('ExpS',j,'R17') = ExpS.l;
IndScen('ExpH',j,'R17') = ExpH.l;
IndScen('ExpT',j,'R17') = ExpT.l;

* (***) Scenario 18
$include zdata6.gms
$include HighOwnPrice6.gms
$include HighElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R18') = Qd.l(j);
IndScen('Pd',j,'R18') = Pd.l(j);
IndScen('Ps',j,'R18') = Ps.l(j);
IndScen('oS',j,'R18') = oS.l(j);
IndScen('oA',j,'R18') = oA.l(j);
IndScen('LdRB',j,'R18') = Ld.l(j,'B');
IndScen('LdRA',j,'R18') = Ld.l(j,'A');
IndScen('LdRC3',j,'R18') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R18') = Ld.l(j,'C1');
IndScen('LdRU',j,'R18') = Ld.l(j,'U');
IndScen('Kd',j,'R18') = Kd.l(j);
IndScen('WRB',j,'R18') = W.l('B');
IndScen('WRA',j,'R18') = W.l('A');
IndScen('WRC3',j,'R18') = W.l('C3');
IndScen('WRC1',j,'R18') = W.l('C1');
IndScen('WRU',j,'R18') = W.l('U');
IndScen('ExpA',j,'R18') = ExpA.l;
IndScen('ExpS',j,'R18') = ExpS.l;
IndScen('ExpH',j,'R18') = ExpH.l;
IndScen('ExpT',j,'R18') = ExpT.l;

************************************************************************************************************************************************************
* Fix the price of LDC, FDC and Occ services, enable Australian gov't subsidy to vary
oA.lo('LDC') = -1.0 ;
oA.up('LDC') = 1.0 ;
Pd.fx('LDC') = BasePrices('LDC') ;
oA.lo('FDC') = -1.0 ;
oA.up('FDC') = 1.0 ;
Pd.fx('FDC') = BasePrices('FDC') ;
oA.lo('Occ') = -1.0 ;
oA.up('Occ') = 1.0 ;
Pd.fx('Occ') = BasePrices('Occ') ;
************************************************************************************************************************************************************

* (***) Scenario 19
$include zdata6.gms
$include LowOwnPrice6.gms
$include LowElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R19') = Qd.l(j);
IndScen('Pd',j,'R19') = Pd.l(j);
IndScen('Ps',j,'R19') = Ps.l(j);
IndScen('oS',j,'R19') = oS.l(j);
IndScen('oA',j,'R19') = oA.l(j);
IndScen('LdRB',j,'R19') = Ld.l(j,'B');
IndScen('LdRA',j,'R19') = Ld.l(j,'A');
IndScen('LdRC3',j,'R19') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R19') = Ld.l(j,'C1');
IndScen('LdRU',j,'R19') = Ld.l(j,'U');
IndScen('Kd',j,'R19') = Kd.l(j);
IndScen('WRB',j,'R19') = W.l('B');
IndScen('WRA',j,'R19') = W.l('A');
IndScen('WRC3',j,'R19') = W.l('C3');
IndScen('WRC1',j,'R19') = W.l('C1');
IndScen('WRU',j,'R19') = W.l('U');
IndScen('ExpA',j,'R19') = ExpA.l;
IndScen('ExpS',j,'R19') = ExpS.l;
IndScen('ExpH',j,'R19') = ExpH.l;
IndScen('ExpT',j,'R19') = ExpT.l;

* (***) Scenario 20
$include zdata6.gms
$include MidOwnPrice6.gms
$include LowElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R20') = Qd.l(j);
IndScen('Pd',j,'R20') = Pd.l(j);
IndScen('Ps',j,'R20') = Ps.l(j);
IndScen('oS',j,'R20') = oS.l(j);
IndScen('oA',j,'R20') = oA.l(j);
IndScen('LdRB',j,'R20') = Ld.l(j,'B');
IndScen('LdRA',j,'R20') = Ld.l(j,'A');
IndScen('LdRC3',j,'R20') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R20') = Ld.l(j,'C1');
IndScen('LdRU',j,'R20') = Ld.l(j,'U');
IndScen('Kd',j,'R20') = Kd.l(j);
IndScen('WRB',j,'R20') = W.l('B');
IndScen('WRA',j,'R20') = W.l('A');
IndScen('WRC3',j,'R20') = W.l('C3');
IndScen('WRC1',j,'R20') = W.l('C1');
IndScen('WRU',j,'R20') = W.l('U');
IndScen('ExpA',j,'R20') = ExpA.l;
IndScen('ExpS',j,'R20') = ExpS.l;
IndScen('ExpH',j,'R20') = ExpH.l;
IndScen('ExpT',j,'R20') = ExpT.l;

* (***) Scenario 21
$include zdata6.gms
$include HighOwnPrice6.gms
$include LowElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R21') = Qd.l(j);
IndScen('Pd',j,'R21') = Pd.l(j);
IndScen('Ps',j,'R21') = Ps.l(j);
IndScen('oS',j,'R21') = oS.l(j);
IndScen('oA',j,'R21') = oA.l(j);
IndScen('LdRB',j,'R21') = Ld.l(j,'B');
IndScen('LdRA',j,'R21') = Ld.l(j,'A');
IndScen('LdRC3',j,'R21') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R21') = Ld.l(j,'C1');
IndScen('LdRU',j,'R21') = Ld.l(j,'U');
IndScen('Kd',j,'R21') = Kd.l(j);
IndScen('WRB',j,'R21') = W.l('B');
IndScen('WRA',j,'R21') = W.l('A');
IndScen('WRC3',j,'R21') = W.l('C3');
IndScen('WRC1',j,'R21') = W.l('C1');
IndScen('WRU',j,'R21') = W.l('U');
IndScen('ExpA',j,'R21') = ExpA.l;
IndScen('ExpS',j,'R21') = ExpS.l;
IndScen('ExpH',j,'R21') = ExpH.l;
IndScen('ExpT',j,'R21') = ExpT.l;

* (***) Scenario 22
$include zdata6.gms
$include LowOwnPrice6.gms
$include MidElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R22') = Qd.l(j);
IndScen('Pd',j,'R22') = Pd.l(j);
IndScen('Ps',j,'R22') = Ps.l(j);
IndScen('oS',j,'R22') = oS.l(j);
IndScen('oA',j,'R22') = oA.l(j);
IndScen('LdRB',j,'R22') = Ld.l(j,'B');
IndScen('LdRA',j,'R22') = Ld.l(j,'A');
IndScen('LdRC3',j,'R22') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R22') = Ld.l(j,'C1');
IndScen('LdRU',j,'R22') = Ld.l(j,'U');
IndScen('Kd',j,'R22') = Kd.l(j);
IndScen('WRB',j,'R22') = W.l('B');
IndScen('WRA',j,'R22') = W.l('A');
IndScen('WRC3',j,'R22') = W.l('C3');
IndScen('WRC1',j,'R22') = W.l('C1');
IndScen('WRU',j,'R22') = W.l('U');
IndScen('ExpA',j,'R22') = ExpA.l;
IndScen('ExpS',j,'R22') = ExpS.l;
IndScen('ExpH',j,'R22') = ExpH.l;
IndScen('ExpT',j,'R22') = ExpT.l;

* (***) Scenario 23
$include zdata6.gms
$include MidOwnPrice6.gms
$include MidElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R23') = Qd.l(j);
IndScen('Pd',j,'R23') = Pd.l(j);
IndScen('Ps',j,'R23') = Ps.l(j);
IndScen('oS',j,'R23') = oS.l(j);
IndScen('oA',j,'R23') = oA.l(j);
IndScen('LdRB',j,'R23') = Ld.l(j,'B');
IndScen('LdRA',j,'R23') = Ld.l(j,'A');
IndScen('LdRC3',j,'R23') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R23') = Ld.l(j,'C1');
IndScen('LdRU',j,'R23') = Ld.l(j,'U');
IndScen('Kd',j,'R23') = Kd.l(j);
IndScen('WRB',j,'R23') = W.l('B');
IndScen('WRA',j,'R23') = W.l('A');
IndScen('WRC3',j,'R23') = W.l('C3');
IndScen('WRC1',j,'R23') = W.l('C1');
IndScen('WRU',j,'R23') = W.l('U');
IndScen('ExpA',j,'R23') = ExpA.l;
IndScen('ExpS',j,'R23') = ExpS.l;
IndScen('ExpH',j,'R23') = ExpH.l;
IndScen('ExpT',j,'R23') = ExpT.l;

* (***) Scenario 24
$include zdata6.gms
$include HighOwnPrice6.gms
$include MidElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R24') = Qd.l(j);
IndScen('Pd',j,'R24') = Pd.l(j);
IndScen('Ps',j,'R24') = Ps.l(j);
IndScen('oS',j,'R24') = oS.l(j);
IndScen('oA',j,'R24') = oA.l(j);
IndScen('LdRB',j,'R24') = Ld.l(j,'B');
IndScen('LdRA',j,'R24') = Ld.l(j,'A');
IndScen('LdRC3',j,'R24') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R24') = Ld.l(j,'C1');
IndScen('LdRU',j,'R24') = Ld.l(j,'U');
IndScen('Kd',j,'R24') = Kd.l(j);
IndScen('WRB',j,'R24') = W.l('B');
IndScen('WRA',j,'R24') = W.l('A');
IndScen('WRC3',j,'R24') = W.l('C3');
IndScen('WRC1',j,'R24') = W.l('C1');
IndScen('WRU',j,'R24') = W.l('U');
IndScen('ExpA',j,'R24') = ExpA.l;
IndScen('ExpS',j,'R24') = ExpS.l;
IndScen('ExpH',j,'R24') = ExpH.l;
IndScen('ExpT',j,'R24') = ExpT.l;

* (***) Scenario 25
$include zdata6.gms
$include LowOwnPrice6.gms
$include HighElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R25') = Qd.l(j);
IndScen('Pd',j,'R25') = Pd.l(j);
IndScen('Ps',j,'R25') = Ps.l(j);
IndScen('oS',j,'R25') = oS.l(j);
IndScen('oA',j,'R25') = oA.l(j);
IndScen('LdRB',j,'R25') = Ld.l(j,'B');
IndScen('LdRA',j,'R25') = Ld.l(j,'A');
IndScen('LdRC3',j,'R25') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R25') = Ld.l(j,'C1');
IndScen('LdRU',j,'R25') = Ld.l(j,'U');
IndScen('Kd',j,'R25') = Kd.l(j);
IndScen('WRB',j,'R25') = W.l('B');
IndScen('WRA',j,'R25') = W.l('A');
IndScen('WRC3',j,'R25') = W.l('C3');
IndScen('WRC1',j,'R25') = W.l('C1');
IndScen('WRU',j,'R25') = W.l('U');
IndScen('ExpA',j,'R25') = ExpA.l;
IndScen('ExpS',j,'R25') = ExpS.l;
IndScen('ExpH',j,'R25') = ExpH.l;
IndScen('ExpT',j,'R25') = ExpT.l;

* (***) Scenario 26
$include zdata6.gms
$include MidOwnPrice6.gms
$include HighElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R26') = Qd.l(j);
IndScen('Pd',j,'R26') = Pd.l(j);
IndScen('Ps',j,'R26') = Ps.l(j);
IndScen('oS',j,'R26') = oS.l(j);
IndScen('oA',j,'R26') = oA.l(j);
IndScen('LdRB',j,'R26') = Ld.l(j,'B');
IndScen('LdRA',j,'R26') = Ld.l(j,'A');
IndScen('LdRC3',j,'R26') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R26') = Ld.l(j,'C1');
IndScen('LdRU',j,'R26') = Ld.l(j,'U');
IndScen('Kd',j,'R26') = Kd.l(j);
IndScen('WRB',j,'R26') = W.l('B');
IndScen('WRA',j,'R26') = W.l('A');
IndScen('WRC3',j,'R26') = W.l('C3');
IndScen('WRC1',j,'R26') = W.l('C1');
IndScen('WRU',j,'R26') = W.l('U');
IndScen('ExpA',j,'R26') = ExpA.l;
IndScen('ExpS',j,'R26') = ExpS.l;
IndScen('ExpH',j,'R26') = ExpH.l;
IndScen('ExpT',j,'R26') = ExpT.l;

* (***) Scenario 27
$include zdata6.gms
$include HighOwnPrice6.gms
$include HighElasticity6.gms
$include LowTeacherRecal6.gms
$include SupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R27') = Qd.l(j);
IndScen('Pd',j,'R27') = Pd.l(j);
IndScen('Ps',j,'R27') = Ps.l(j);
IndScen('oS',j,'R27') = oS.l(j);
IndScen('oA',j,'R27') = oA.l(j);
IndScen('LdRB',j,'R27') = Ld.l(j,'B');
IndScen('LdRA',j,'R27') = Ld.l(j,'A');
IndScen('LdRC3',j,'R27') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R27') = Ld.l(j,'C1');
IndScen('LdRU',j,'R27') = Ld.l(j,'U');
IndScen('Kd',j,'R27') = Kd.l(j);
IndScen('WRB',j,'R27') = W.l('B');
IndScen('WRA',j,'R27') = W.l('A');
IndScen('WRC3',j,'R27') = W.l('C3');
IndScen('WRC1',j,'R27') = W.l('C1');
IndScen('WRU',j,'R27') = W.l('U');
IndScen('ExpA',j,'R27') = ExpA.l;
IndScen('ExpS',j,'R27') = ExpS.l;
IndScen('ExpH',j,'R27') = ExpH.l;
IndScen('ExpT',j,'R27') = ExpT.l;

* (***) Scenario 28
$include zdata6.gms
$include LowOwnPrice6.gms
$include LowElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R28') = Qd.l(j);
IndScen('Pd',j,'R28') = Pd.l(j);
IndScen('Ps',j,'R28') = Ps.l(j);
IndScen('oS',j,'R28') = oS.l(j);
IndScen('oA',j,'R28') = oA.l(j);
IndScen('LdRB',j,'R28') = Ld.l(j,'B');
IndScen('LdRA',j,'R28') = Ld.l(j,'A');
IndScen('LdRC3',j,'R28') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R28') = Ld.l(j,'C1');
IndScen('LdRU',j,'R28') = Ld.l(j,'U');
IndScen('Kd',j,'R28') = Kd.l(j);
IndScen('WRB',j,'R28') = W.l('B');
IndScen('WRA',j,'R28') = W.l('A');
IndScen('WRC3',j,'R28') = W.l('C3');
IndScen('WRC1',j,'R28') = W.l('C1');
IndScen('WRU',j,'R28') = W.l('U');
IndScen('ExpA',j,'R28') = ExpA.l;
IndScen('ExpS',j,'R28') = ExpS.l;
IndScen('ExpH',j,'R28') = ExpH.l;
IndScen('ExpT',j,'R28') = ExpT.l;

* (***) Scenario 29
$include zdata6.gms
$include MidOwnPrice6.gms
$include LowElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R29') = Qd.l(j);
IndScen('Pd',j,'R29') = Pd.l(j);
IndScen('Ps',j,'R29') = Ps.l(j);
IndScen('oS',j,'R29') = oS.l(j);
IndScen('oA',j,'R29') = oA.l(j);
IndScen('LdRB',j,'R29') = Ld.l(j,'B');
IndScen('LdRA',j,'R29') = Ld.l(j,'A');
IndScen('LdRC3',j,'R29') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R29') = Ld.l(j,'C1');
IndScen('LdRU',j,'R29') = Ld.l(j,'U');
IndScen('Kd',j,'R29') = Kd.l(j);
IndScen('WRB',j,'R29') = W.l('B');
IndScen('WRA',j,'R29') = W.l('A');
IndScen('WRC3',j,'R29') = W.l('C3');
IndScen('WRC1',j,'R29') = W.l('C1');
IndScen('WRU',j,'R29') = W.l('U');
IndScen('ExpA',j,'R29') = ExpA.l;
IndScen('ExpS',j,'R29') = ExpS.l;
IndScen('ExpH',j,'R29') = ExpH.l;
IndScen('ExpT',j,'R29') = ExpT.l;

* (***) Scenario 30
$include zdata6.gms
$include HighOwnPrice6.gms
$include LowElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R30') = Qd.l(j);
IndScen('Pd',j,'R30') = Pd.l(j);
IndScen('Ps',j,'R30') = Ps.l(j);
IndScen('oS',j,'R30') = oS.l(j);
IndScen('oA',j,'R30') = oA.l(j);
IndScen('LdRB',j,'R30') = Ld.l(j,'B');
IndScen('LdRA',j,'R30') = Ld.l(j,'A');
IndScen('LdRC3',j,'R30') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R30') = Ld.l(j,'C1');
IndScen('LdRU',j,'R30') = Ld.l(j,'U');
IndScen('Kd',j,'R30') = Kd.l(j);
IndScen('WRB',j,'R30') = W.l('B');
IndScen('WRA',j,'R30') = W.l('A');
IndScen('WRC3',j,'R30') = W.l('C3');
IndScen('WRC1',j,'R30') = W.l('C1');
IndScen('WRU',j,'R30') = W.l('U');
IndScen('ExpA',j,'R30') = ExpA.l;
IndScen('ExpS',j,'R30') = ExpS.l;
IndScen('ExpH',j,'R30') = ExpH.l;
IndScen('ExpT',j,'R30') = ExpT.l;

* (***) Scenario 31
$include zdata6.gms
$include LowOwnPrice6.gms
$include MidElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R31') = Qd.l(j);
IndScen('Pd',j,'R31') = Pd.l(j);
IndScen('Ps',j,'R31') = Ps.l(j);
IndScen('oS',j,'R31') = oS.l(j);
IndScen('oA',j,'R31') = oA.l(j);
IndScen('LdRB',j,'R31') = Ld.l(j,'B');
IndScen('LdRA',j,'R31') = Ld.l(j,'A');
IndScen('LdRC3',j,'R31') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R31') = Ld.l(j,'C1');
IndScen('LdRU',j,'R31') = Ld.l(j,'U');
IndScen('Kd',j,'R31') = Kd.l(j);
IndScen('WRB',j,'R31') = W.l('B');
IndScen('WRA',j,'R31') = W.l('A');
IndScen('WRC3',j,'R31') = W.l('C3');
IndScen('WRC1',j,'R31') = W.l('C1');
IndScen('WRU',j,'R31') = W.l('U');
IndScen('ExpA',j,'R31') = ExpA.l;
IndScen('ExpS',j,'R31') = ExpS.l;
IndScen('ExpH',j,'R31') = ExpH.l;
IndScen('ExpT',j,'R31') = ExpT.l;

* (***) Scenario 32
$include zdata6.gms
$include MidOwnPrice6.gms
$include MidElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R32') = Qd.l(j);
IndScen('Pd',j,'R32') = Pd.l(j);
IndScen('Ps',j,'R32') = Ps.l(j);
IndScen('oS',j,'R32') = oS.l(j);
IndScen('oA',j,'R32') = oA.l(j);
IndScen('LdRB',j,'R32') = Ld.l(j,'B');
IndScen('LdRA',j,'R32') = Ld.l(j,'A');
IndScen('LdRC3',j,'R32') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R32') = Ld.l(j,'C1');
IndScen('LdRU',j,'R32') = Ld.l(j,'U');
IndScen('Kd',j,'R32') = Kd.l(j);
IndScen('WRB',j,'R32') = W.l('B');
IndScen('WRA',j,'R32') = W.l('A');
IndScen('WRC3',j,'R32') = W.l('C3');
IndScen('WRC1',j,'R32') = W.l('C1');
IndScen('WRU',j,'R32') = W.l('U');
IndScen('ExpA',j,'R32') = ExpA.l;
IndScen('ExpS',j,'R32') = ExpS.l;
IndScen('ExpH',j,'R32') = ExpH.l;
IndScen('ExpT',j,'R32') = ExpT.l;

* (***) Scenario 33
$include zdata6.gms
$include HighOwnPrice6.gms
$include MidElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R33') = Qd.l(j);
IndScen('Pd',j,'R33') = Pd.l(j);
IndScen('Ps',j,'R33') = Ps.l(j);
IndScen('oS',j,'R33') = oS.l(j);
IndScen('oA',j,'R33') = oA.l(j);
IndScen('LdRB',j,'R33') = Ld.l(j,'B');
IndScen('LdRA',j,'R33') = Ld.l(j,'A');
IndScen('LdRC3',j,'R33') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R33') = Ld.l(j,'C1');
IndScen('LdRU',j,'R33') = Ld.l(j,'U');
IndScen('Kd',j,'R33') = Kd.l(j);
IndScen('WRB',j,'R33') = W.l('B');
IndScen('WRA',j,'R33') = W.l('A');
IndScen('WRC3',j,'R33') = W.l('C3');
IndScen('WRC1',j,'R33') = W.l('C1');
IndScen('WRU',j,'R33') = W.l('U');
IndScen('ExpA',j,'R33') = ExpA.l;
IndScen('ExpS',j,'R33') = ExpS.l;
IndScen('ExpH',j,'R33') = ExpH.l;
IndScen('ExpT',j,'R33') = ExpT.l;

* (***) Scenario 34
$include zdata6.gms
$include LowOwnPrice6.gms
$include HighElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R34') = Qd.l(j);
IndScen('Pd',j,'R34') = Pd.l(j);
IndScen('Ps',j,'R34') = Ps.l(j);
IndScen('oS',j,'R34') = oS.l(j);
IndScen('oA',j,'R34') = oA.l(j);
IndScen('LdRB',j,'R34') = Ld.l(j,'B');
IndScen('LdRA',j,'R34') = Ld.l(j,'A');
IndScen('LdRC3',j,'R34') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R34') = Ld.l(j,'C1');
IndScen('LdRU',j,'R34') = Ld.l(j,'U');
IndScen('Kd',j,'R34') = Kd.l(j);
IndScen('WRB',j,'R34') = W.l('B');
IndScen('WRA',j,'R34') = W.l('A');
IndScen('WRC3',j,'R34') = W.l('C3');
IndScen('WRC1',j,'R34') = W.l('C1');
IndScen('WRU',j,'R34') = W.l('U');
IndScen('ExpA',j,'R34') = ExpA.l;
IndScen('ExpS',j,'R34') = ExpS.l;
IndScen('ExpH',j,'R34') = ExpH.l;
IndScen('ExpT',j,'R34') = ExpT.l;

* (***) Scenario 35
$include zdata6.gms
$include MidOwnPrice6.gms
$include HighElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R35') = Qd.l(j);
IndScen('Pd',j,'R35') = Pd.l(j);
IndScen('Ps',j,'R35') = Ps.l(j);
IndScen('oS',j,'R35') = oS.l(j);
IndScen('oA',j,'R35') = oA.l(j);
IndScen('LdRB',j,'R35') = Ld.l(j,'B');
IndScen('LdRA',j,'R35') = Ld.l(j,'A');
IndScen('LdRC3',j,'R35') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R35') = Ld.l(j,'C1');
IndScen('LdRU',j,'R35') = Ld.l(j,'U');
IndScen('Kd',j,'R35') = Kd.l(j);
IndScen('WRB',j,'R35') = W.l('B');
IndScen('WRA',j,'R35') = W.l('A');
IndScen('WRC3',j,'R35') = W.l('C3');
IndScen('WRC1',j,'R35') = W.l('C1');
IndScen('WRU',j,'R35') = W.l('U');
IndScen('ExpA',j,'R35') = ExpA.l;
IndScen('ExpS',j,'R35') = ExpS.l;
IndScen('ExpH',j,'R35') = ExpH.l;
IndScen('ExpT',j,'R35') = ExpT.l;

* (***) Scenario 36
$include zdata6.gms
$include HighOwnPrice6.gms
$include HighElasticity6.gms
$include LowTeacherRecal6.gms
$include NoSupplyElas6.gms
$include zcalc6.gms
$include NPA_ECE_Reform6.gms
$include LowTeacherDemands6.gms
solve Policy maximising NSW using nlp ;
IndScen('Qd',j,'R36') = Qd.l(j);
IndScen('Pd',j,'R36') = Pd.l(j);
IndScen('Ps',j,'R36') = Ps.l(j);
IndScen('oS',j,'R36') = oS.l(j);
IndScen('oA',j,'R36') = oA.l(j);
IndScen('LdRB',j,'R36') = Ld.l(j,'B');
IndScen('LdRA',j,'R36') = Ld.l(j,'A');
IndScen('LdRC3',j,'R36') = Ld.l(j,'C3');
IndScen('LdRC1',j,'R36') = Ld.l(j,'C1');
IndScen('LdRU',j,'R36') = Ld.l(j,'U');
IndScen('Kd',j,'R36') = Kd.l(j);
IndScen('WRB',j,'R36') = W.l('B');
IndScen('WRA',j,'R36') = W.l('A');
IndScen('WRC3',j,'R36') = W.l('C3');
IndScen('WRC1',j,'R36') = W.l('C1');
IndScen('WRU',j,'R36') = W.l('U');
IndScen('ExpA',j,'R36') = ExpA.l;
IndScen('ExpS',j,'R36') = ExpS.l;
IndScen('ExpH',j,'R36') = ExpH.l;
IndScen('ExpT',j,'R36') = ExpT.l;


option IndScen:0:2:1;
Display IndScen ;

